import lejos.hardware.motor.EV3LargeRegulatedMotor;
import lejos.hardware.port.MotorPort;
import lejos.hardware.port.SensorPort;
import lejos.hardware.sensor.EV3GyroSensor;
import lejos.utility.Delay;
/**
 * This class describes a Roberta-robot, that uses a gyrosensor to move along a squared path.
 */
public class GyRoberta {
	
	private EV3LargeRegulatedMotor engineR = new EV3LargeRegulatedMotor(MotorPort.B);
	private EV3LargeRegulatedMotor engineL = new EV3LargeRegulatedMotor(MotorPort.C);
	private EV3GyroSensor gyroSensor = new EV3GyroSensor(SensorPort.S3);
	
	private float[] sample;
	
	GyRoberta() {
		gyroSensor.setCurrentMode("Angle");
		sample = new float[gyroSensor.sampleSize()];
		gyroSensor.fetchSample(sample, 0);
		Delay.msDelay(1000);
	}
	
	private void driveSquare() {
		engineR.setSpeed(250);
		engineL.setSpeed(250);
		final int ANGLE = 90;
				
		for (int i = 1; i <= 4; i++) {
			engineR.forward();
			engineL.forward();
			Delay.msDelay(2000);
			engineR.stop(true);
			 do {
				gyroSensor.fetchSample(sample, 0);
			} while (sample[0] > (-ANGLE * i));
			engineL.stop(true);
		}
	}
	
	public static void main(String[] args) {
		GyRoberta roberta = new GyRoberta();
		roberta.driveSquare();
	}
}
