import lejos.hardware.motor.EV3LargeRegulatedMotor;
import lejos.hardware.sensor.EV3UltrasonicSensor;
import lejos.robotics.subsumption.Behavior;

/**
 * This class implements the robot's behavior after an obstacle is detected by ultrasonic-sensor.
 * The robot turns randomly to the left or to the right until there's at least 1m of free path in front of it.
 */
public class UltrasonicCollision implements Behavior {
	protected final EV3LargeRegulatedMotor engineR;
	protected final EV3LargeRegulatedMotor engineL;
	private final EV3UltrasonicSensor uSensor;
	private float[] distanceSample;
	
	private boolean isActive = false;
	
	UltrasonicCollision(EV3UltrasonicSensor sensor, EV3LargeRegulatedMotor motorR, EV3LargeRegulatedMotor motorL) {
		engineR = motorR;
		engineL = motorL;
		uSensor = sensor;
		uSensor.setCurrentMode("Distance");
		distanceSample = new float[uSensor.sampleSize()];
	}
	
	public void action() {
		isActive = true;
		//turn to left or right randomly with half the motorspeed
		double rand = Math.random();
		engineR.setSpeed(Roberta.SPEED * 0.5F);
		engineL.setSpeed(Roberta.SPEED * 0.5F);
		if (rand < 0.5) {
			engineR.forward();
			engineL.backward();
		}
		else {
			engineL.forward();
			engineR.backward();
		}
		//wait until 1m of path is free or behavior is suppressed
		while (isActive && (distanceSample[0] < 1.0)) {
			uSensor.fetchSample(distanceSample, 0);
		}
		engineL.stop(true);
		engineR.stop(true);
	}
	
	public void suppress() {
		isActive = false;
	}
	
	public boolean takeControl() {
		uSensor.fetchSample(distanceSample, 0);
		return (distanceSample[0] < 0.30) ;
	}
}