import lejos.hardware.motor.EV3LargeRegulatedMotor;
import lejos.hardware.sensor.EV3TouchSensor;
import lejos.robotics.subsumption.Behavior;

/**
 * This class implements the robot's behavior after one of its bumpers touches an obstacle.
 * The robot moves backwards with different motorspeeds (on an arc) until the slower motor has turned 180 degrees.
 * Depending on which bumper detected the obstacle, either the left or the right motor is turning slower.
 * After that the robot faces away from the obstacle and can proceed to move forward.
 */
public class BumperCollision implements Behavior {
	protected final EV3LargeRegulatedMotor engineR;
	protected final EV3LargeRegulatedMotor engineL;
	private final EV3TouchSensor tSensorR;
	private final EV3TouchSensor tSensorL;

	private float[] rBumperSample;
	private float[] lBumperSample;

	private boolean bLeftBumper = false;
	private boolean bRightBumper = false;
	private boolean isActive = false;
	private final float SPEEDFACTOR = 0.5F;
	private final int LIMITANGLE = 180;
	
	BumperCollision(EV3TouchSensor touchR, EV3TouchSensor touchL, EV3LargeRegulatedMotor motorR, EV3LargeRegulatedMotor motorL) {
		engineR = motorR;
		engineL = motorL;
		tSensorR = touchR;
		tSensorL = touchL;
		tSensorR.setCurrentMode("Touch");
		tSensorL.setCurrentMode("Touch");
		rBumperSample = new float[tSensorR.sampleSize()];
		lBumperSample = new float[tSensorL.sampleSize()];		
	}
	
	private void resetBoolean() {
		bLeftBumper = false;
		bRightBumper = false;
	}

	public void action() {
		isActive = true;
		if (bLeftBumper) {
			engineL.setSpeed(Roberta.SPEED * SPEEDFACTOR);
		}
		else if (bRightBumper) {
			engineR.setSpeed(Roberta.SPEED * SPEEDFACTOR);
		}
		engineR.resetTachoCount();
		engineL.resetTachoCount();
		engineR.backward();
		engineL.backward();
		while (isActive && ((engineR.getTachoCount() > -LIMITANGLE) || (engineL.getTachoCount() > -LIMITANGLE))) {}
		engineL.stop(true);
		engineR.stop(true);
	}
	
	public void suppress() {
		isActive = false;
	}
	
	public boolean takeControl() {
		resetBoolean();
		tSensorR.fetchSample(rBumperSample, 0);
		tSensorL.fetchSample(lBumperSample, 0);
		bRightBumper = (rBumperSample[0] == 1.0);
		bLeftBumper = (lBumperSample[0] == 1.0);
		return (bRightBumper || bLeftBumper);
	}
}