import lejos.hardware.lcd.LCD;
import lejos.hardware.motor.EV3LargeRegulatedMotor;
import lejos.hardware.port.MotorPort;
import lejos.hardware.port.SensorPort;
import lejos.hardware.sensor.EV3TouchSensor;
import lejos.hardware.sensor.EV3UltrasonicSensor;
import lejos.robotics.subsumption.Arbitrator;
import lejos.robotics.subsumption.Behavior;

/**
 * This class describes a Roberta-robot that can move around in a room while avoiding obstacles.
 * It uses four Behavior-classes as seen in its constructor. MoveForward has lowest priority, EmergencyStop has highest priority.
 * The robot uses either its ultrasonic-sensor or its bumpers to detect an obstacle.
 */
public class Roberta {
	EV3LargeRegulatedMotor engineR = new EV3LargeRegulatedMotor(MotorPort.B);
	EV3LargeRegulatedMotor engineL = new EV3LargeRegulatedMotor(MotorPort.C);
	EV3UltrasonicSensor uSensor = new EV3UltrasonicSensor(SensorPort.S4);
	EV3TouchSensor bumperR = new EV3TouchSensor(SensorPort.S1);
	EV3TouchSensor bumperL = new EV3TouchSensor(SensorPort.S2);
	
	Arbitrator arby;
	Behavior[] behaviorList = new Behavior[4];
	
	public final static int SPEED = 360;
	
	Roberta() {
		behaviorList[0] = new MoveForward(engineR, engineL);
		behaviorList[1] = new UltrasonicCollision(uSensor, engineR, engineL);
		behaviorList[2] = new BumperCollision(bumperR, bumperL, engineR, engineL);
		behaviorList[3] = new EmergencyStop(engineR, engineL);
		arby = new Arbitrator(behaviorList);
	}
	
	public static void main(String[] args) {
		Roberta autonomousRoberta = new Roberta();
		LCD.drawString("Arbitrating", 0, 0);
		autonomousRoberta.arby.start();
	}
}
