	public static void main (String[] args) {
		int scanTime, searchTime, applyTime;
		
		MotorController motors = new MotorController();
		CubeScanner scanner = new CubeScanner(motors);
		RubiksCube cube = new RubiksCube();
		CubeAlgorithm solver = new CubeAlgorithm();
		Stopwatch timer = new Stopwatch();
		motors.init();
				
		LCD.drawString("Start Scanning?",0,0);
		Button.ENTER.waitForPress();
		
		//Scanning starts here
		timer.reset();
		scanner.scanCube(cube);
		while (cube.completeIntegrity() == false) {
			LCD.clear();
			LCD.drawString("Scan Failure", 0, 0);
			LCD.drawString("Rescan?", 0, 1);
			Button.ENTER.waitForPress();
			timer.reset();
			motors.rotate();
			cube.resetNull();
			scanner.scanCube(cube);
		}
		scanTime = timer.elapsed();	
		
		cube.printEV3();
		LCD.drawString("Start Search?", 0, 7);
		Button.ENTER.waitForPress();
		
		//Calculation of solution starts here
		cube.setRecording(true);
		timer.reset();
		solver.firstLevelEdges(cube);
		cube.shortenSolution();
		solver.firstLevelCorners(cube);
		cube.shortenSolution();
		solver.secondLevelEdges(cube);
		cube.shortenSolution();
		solver.orientLLEdges(cube);
		cube.shortenSolution();
		solver.permuteLLCorners(cube);
		cube.shortenSolution();
		solver.orientLLCorners(cube);
		cube.shortenSolution();
		solver.permuteLLedges(cube);
		cube.shortenSolution();
		searchTime = timer.elapsed();
				
		LCD.clear();
		LCD.drawString("Solution found", 0, 0);
		LCD.drawString(""+cube.solutionIndex, 0, 1);
		LCD.drawString("Apply?", 0, 2);
		Button.ENTER.waitForPress();
		
		//Solution is applied to cube here
		timer.reset();
		motors.maneuver(cube.solution, cube.solutionIndex);
		applyTime = timer.elapsed();
		
		//Times are displayed
		LCD.clear();
		LCD.drawString("Scan: "+ scanTime/1000.0F, 0, 0);
		LCD.drawString("Search: "+ searchTime/1000.0F, 0, 1);
		LCD.drawString("Apply: "+ applyTime/1000.0F, 0, 2);
		
		Button.ENTER.waitForPress();
	}